#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['cards']

package_data = \
{'': ['*']}

package_dir = \
{'': 'src'}

install_requires = \
['tinydb==4.3.0', 'typer==0.3.2', 'rich==9.3.0']

extras_require = \
{'test': ['pytest==6.0.0rc1', 'pytest-cov']}

entry_points = \
{'console_scripts': ['cards = cards:app']}

setup(name='cards',
      version='1.0.0',
      description='Top-level package for cards.',
      author='Brian Okken',
      author_email='brian+pypi@pythontest.com',
      url='https://github.com/okken/cards',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
